@@ -179,6 +179,11 @@ sans =%(SANS)s
 pypi =%(WAREHOUSE)s
 """ % locals()
 
+FILTERWARNINGS = ('-W "ignore:setup.py install is deprecated" '
+                  '-W "ignore:easy_install command is deprecated" '
+                  '-W "ignore:Support for \`[tool.setuptools]\` in \`pyproject.toml\`" '
+                  '-W "ignore:The namespace_packages parameter is deprecated"')
+
 
 # Open files as UTF-8
 if sys.version_info[0] >= 3:
@@ -267,11 +272,12 @@ class Setuptools(object):
         return env
 
     def is_valid_package(self):
-        return isfile('setup.py') or isfile('setup.cfg')
+        return isfile('setup.py') or isfile('setup.cfg') or isfile('pyproject.toml')
 
     def check_valid_package(self):
         if not self.is_valid_package():
-            err_exit('viewdoc: No setup.py in %s' % os.getcwd())
+            err_exit('viewdoc: No setup in %s\n'
+                     'Expected setup.py and/or setup.cfg and/or pyproject.toml' % os.getcwd())
 
     def get_long_description(self):
         parser = ConfigParser(warn)
@@ -281,14 +287,19 @@ class Setuptools(object):
 
         rc, long_description = self._run_setup_py(['--long-description'])
 
-        if rc != 0:
-            err_exit('viewdoc: Bad setup in %s' % os.getcwd())
-        if sys.version_info[0] >= 3:
-            try:
-                return long_description.decode('utf-8')
-            except UnicodeDecodeError as e:
-                err_exit('viewdoc: Error reading long description: %s' % (e,))
-        return long_description
+        if rc == 0:
+            if sys.version_info[0] >= 3:
+                try:
+                    long_description = long_description.decode('utf-8')
+                except UnicodeDecodeError as e:
+                    err_exit('viewdoc: Error reading long description: %s' % (e,))
+
+            if long_description.strip() == 'UNKNOWN':
+                parser.warn('Missing metadata: long_description')
+            if not parser.warnings:
+                return long_description
+
+        err_exit('viewdoc: Bad setup in %s' % os.getcwd())
 
     def _run_setup_py(self, args):
         """Run setup.py with monkey-patched setuptools.
@@ -297,12 +308,13 @@ class Setuptools(object):
         setup.py.
         """
         python = self.python
-        run_setup = 'from jarn.viewdoc import setup; setup.run(%(args)r)'
+        filterwarnings = FILTERWARNINGS
 
+        run_setup = 'from jarn.viewdoc import setup; setup.run(%(args)r)'
         setup_py = '-c"%s"' % (run_setup % locals())
 
         rc, stdoutdata = self.process.popen(
-            '"%(python)s" %(setup_py)s' % locals())
+            '"%(python)s" %(filterwarnings)s %(setup_py)s' % locals())
 
         return rc, stdoutdata
 
@@ -329,7 +341,7 @@ class Docutils(object):
         except (IOError, OSError) as e:
             err_exit('viewdoc: Error writing %s: %s' % (outfile, e.strerror or e))
 
-    def convert_string(self, rest):
+    def render_string(self, rest):
         """Convert a reST string to an HTML string.
         """
         try:
@@ -359,7 +371,7 @@ class Docutils(object):
     def publish_string(self, rest, outfile, styles=''):
         """Render a reST string as HTML.
         """
-        html = self.convert_string(rest)
+        html = self.render_string(rest)
         html = self.strip_xml_header(html)
         html = self.apply_styles(html, styles)
         self.write_file(html, outfile)
